Compare commits

...
Sign in to create a new pull request.

41 commits

Author SHA1 Message Date
Mamoru TASAKA
8b2bca7072 3.6.2 2025-12-23 17:49:21 +09:00
Mamoru TASAKA
542f068745 3.6.1 2025-11-04 16:49:25 +09:00
Mamoru TASAKA
25e0231258 3.6.0 2025-10-01 17:39:45 +09:00
Mamoru TASAKA
f731e4b04c update to the latest git 2025-09-25 10:51:20 +09:00
Python Maint
998627493f Rebuilt for Python 3.14.0rc3 bytecode 2025-09-19 12:10:23 +02:00
Mamoru TASAKA
71ee023d82 update to the latest git 2025-09-17 23:51:28 +09:00
Mamoru TASAKA
7a470d628d Update to the latest git (20250908gitac4c5fc) 2025-09-08 22:10:57 +09:00
Mamoru TASAKA
75916e386e Update to the latest git (20250822gitcb4e816) 2025-08-24 22:47:45 +09:00
Python Maint
8f08ccff08 Rebuilt for Python 3.14.0rc2 bytecode 2025-08-15 12:41:00 +02:00
Mamoru TASAKA
5efc170cee Update to the latest git (20250810git987890d) 2025-08-12 16:13:18 +09:00
Mamoru TASAKA
e71ed456e5 Update to the latest git (20250729giteb8fa4c) 2025-07-29 16:28:55 +09:00
Mamoru TASAKA
cef03d3875 raise core_least_ver 2025-07-29 16:27:47 +09:00
Fedora Release Engineering
bad1912f94 Rebuilt for https://fedoraproject.org/wiki/Fedora_43_Mass_Rebuild 2025-07-23 18:02:37 +00:00
Mamoru TASAKA
9a09f5e1be Update to the latest git (20250714gita426778) 2025-07-14 16:57:25 +09:00
Mamoru TASAKA
364e85a00c Update to the latest git (20250623git64bcb0f) 2025-06-30 17:25:33 +09:00
Mamoru TASAKA
ba7a84f681 Update to the latest git (20250616gitd333ad8) 2025-06-19 14:39:00 +09:00
Python Maint
55a54f4976 Rebuilt for Python 3.14 2025-06-03 00:19:20 +02:00
Mamoru TASAKA
ec6f081674 update to the latest git 2025-05-04 22:52:28 +09:00
Mamoru TASAKA
47451b9148 Update %cmake macro usage (to prepare for cmake 4 and related changes) 2025-04-17 11:34:23 +09:00
Mamoru TASAKA
2126b95478 Use recent compiler standard 2025-03-14 11:21:52 +09:00
Mamoru TASAKA
a7fa7ebf16 update to the latest git 2025-02-18 22:20:19 +09:00
Mamoru TASAKA
c35705ed50 Add BR: json-c for weather module 2025-02-16 17:00:24 +09:00
Mamoru TASAKA
259639b411 update to the latest git 2025-02-14 14:27:30 +09:00
Mamoru TASAKA
66494a4691 update to the latest git 2025-02-13 14:39:16 +09:00
Mamoru TASAKA
837e03f68d 20250120git9cc48a3 2025-01-30 16:12:08 +09:00
Mamoru TASAKA
a183aa0a34 Update to the latest git (20250118git18ad738) 2025-01-19 16:48:41 +09:00
Fedora Release Engineering
ec37db85c1 Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild 2025-01-16 13:12:03 +00:00
Mamoru TASAKA
441e2d9828 Update to the latest git (20241217gitf8ad97e) 2024-12-17 21:44:11 +09:00
Mamoru TASAKA
89b831ee0b Update to the latest git (20241207gitce518e9) 2024-12-08 16:35:09 +09:00
Mamoru TASAKA
09ba42b28d Update to the latest git (3.5.99-20241117gite9d3fcd) 2024-11-19 15:54:26 +09:00
Mamoru TASAKA
080fec0e1e Update to the latest git (20241024gitd965212) 2024-10-24 09:37:16 +09:00
Mamoru TASAKA
bc38f9be39 keep line number when modifying source 2024-10-12 12:58:01 +09:00
Mamoru TASAKA
f970a0cddb python subpackage is now arch-dependent 2024-10-07 08:02:22 +09:00
Mamoru TASAKA
7b5b6f863d Update to the latest git (20241007git019f49f)
Update to the latest git (20241007git019f49f)
Update to the latest git (20241007git019f49f)
Update to the latest git (20241007git019f49f)
Update to the latest git (20241007git019f49f)
Update to the latest git (20241007git019f49f)
Update to the latest git (20241007git019f49f)
Update to the latest git (20241007git019f49f)
Update to the latest git (20241007git019f49f)
Update to the latest git (20241007git019f49f)
Update to the latest git (20241007git019f49f)
Update to the latest git (20241007git019f49f)
2024-10-07 07:07:07 +09:00
Mamoru TASAKA
f93eacc198 BR: ayatana-indicator3-0.4 for Messaging-Menu support 2024-09-22 17:17:13 +09:00
Mamoru TASAKA
70d0d4f72c Require gdk-pixbuf2-modules-extra if available
Require gdk-pixbuf2-modules-extra if available
Require gdk-pixbuf2-modules-extra if available
Require gdk-pixbuf2-modules-extra if available
Require gdk-pixbuf2-modules-extra if available
Require gdk-pixbuf2-modules-extra if available
Require gdk-pixbuf2-modules-extra if available
Require gdk-pixbuf2-modules-extra if available
Require gdk-pixbuf2-modules-extra if available
Require gdk-pixbuf2-modules-extra if available
Require gdk-pixbuf2-modules-extra if available
Require gdk-pixbuf2-modules-extra if available
2024-08-16 13:46:37 +09:00
Fedora Release Engineering
e32a678d17 Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild 2024-07-17 18:52:03 +00:00
Python Maint
332f651232 Rebuilt for Python 3.13 2024-06-07 13:15:13 +02:00
Mamoru TASAKA
212673a2a0 Update to the latest git (20240501git9901f7d) 2024-05-04 22:50:55 +09:00
Mamoru TASAKA
6194bf0f6a Fix invalid SPDX tag 2024-03-27 21:10:47 +09:00
Mamoru TASAKA
1df9154c53 SPDX migration 2024-03-15 11:45:50 +09:00
8 changed files with 218 additions and 201 deletions

38
License-analysis.txt Normal file
View file

@ -0,0 +1,38 @@
GPL-3.0-or-later
(base)
GPL-2.0-or-later
Dbus/demos/demo_bash/demo_bash
Dbus/demos/demo_bash/demo_bash.sh
Dbus/demos/demo_mono/demo_mono.cs
Dbus/demos/demo_python/demo_python
Dbus/demos/demo_vala/demo_vala.vala
Dbus/interfaces/mono/CDApplet.cs
Dbus/interfaces/vala/CDApplet.vala
Dbus/interfaces/vala/src/CDApplet.c
Doncky/data/nvidia-config
Network-Monitor/data/access-point
Network-Monitor/data/wifi
System-Monitor/data/nvidia-config
netspeed/data/netspeed
systray/src/gtk3/fixedtip.c
systray/src/gtk3/fixedtip.h
systray/src/gtk3/main.c
systray/src/gtk3/main.h
systray/src/gtk3/na-tray.c
LGPL-2.1-only OR LGPL-3.0-only
MeMenu/src/about-me-menu-item.c unused
MeMenu/src/about-me-menu-item.h unused
LGPL-2.1-or-later
Global-Menu/src/MwmUtil.h
systray/src/gtk3/na-tray-child.c
systray/src/gtk3/na-tray-child.h
systray/src/gtk3/na-tray-manager.c
systray/src/gtk3/na-tray-manager.h
systray/src/gtk3/na-tray.h
systray/src/gtk3/testtray.c
copyright says:
GPL-2.0-only icons https://github.com/mk-pmb/ubuntu-icon-theme-humanity

View file

@ -60,8 +60,12 @@ sed -i -e '\@SCOOBY_DO@,\@endif@d' -e '\@with_scooby_do@d' CMakeLists.txt
pushd desklet-rendering
rm -f data/starcraft2.png
sed -i -e '\@starcraft2@d' data/CMakeLists.txt
sed -i -e '\@_register_desklet_decorations.*none@i REMOVE_TO_HERE' src/rendering-desklet-decorations.c
sed -i -e '\@_register_desklet_decorations.*futuristic@,\@REMOVE_TO_HERE@d' src/rendering-desklet-decorations.c
sed -i src/rendering-desklet-decorations.c -e '\@_register_desklet_decorations.*none@i REMOVE_TO_HERE'
sed -i src/rendering-desklet-decorations.c \
-e '\@_register_desklet_decorations.*futuristic@,\@REMOVE_TO_HERE@s@^@REMOVE_HERE@'
sed -i src/rendering-desklet-decorations.c -e '\@_register_desklet_decorations.*futuristic@d'
sed -i src/rendering-desklet-decorations.c \
-e '\@REMOVE_HERE@s@^.*$@@'
popd
cp -p ./weather/data/themes/Classic/na.png ./weather/data/broken.png

View file

@ -1,61 +1,66 @@
%global urlver 3.5
%global mainver 3.5.0
%global urlver 3.6
%global mainver 3.6.2
%global core_least_ver 3.5.0
%global core_least_ver 3.6.0
#%%global use_git 1
%global gitdate 20210730
%global githash f24f7699e69b0e25e5e7674c4841dcefc4e6b61d
%dnl %global use_git 1
%global gitdate 20250922
%global githash f45372c1fbce5dc9a34a991ff6e2485d39603279
%global shorthash %(c=%{githash} ; echo ${c:0:7})
%global tarballver %{mainver}%{?use_git:-%{gitdate}git%{shorthash}}
%global baserelease 2
%global baserelease 1
%dnl %global alphatag .rc9
%global ruby_vendorlib %(ruby -rrbconfig -e "puts RbConfig::CONFIG['vendorlibdir']")
%global dbus_datadir %{_datadir}/cairo-dock/plug-ins/Dbus
%global build_unstable 1
%undefine _strict_symbol_defs_build
##########################################
%global flagrel %{nil}
%global use_gcc_strict_sanitize 0
%if 0%{?use_gcc_strict_sanitize} >= 1
%global flagrel %{flagrel}.san
%endif
##########################################
Name: cairo-dock-plug-ins
Version: %{mainver}%{?use_git:^%{gitdate}git%{shorthash}}
Release: %{baserelease}%{?dist}
Release: %{baserelease}%{?alphatag}%{?dist}%{flagrel}
Summary: Plug-ins files for Cairo-Dock
License: GPLv3+
# SPDX confirmed
License: GPL-3.0-or-later AND GPL-2.0-or-later AND LGPL-2.1-or-later AND GPL-2.0-only
URL: http://glx-dock.org/
#Source0: http://launchpad.net/cairo-dock-plug-ins/%%{urlver}/%%{mainver}/+download/cairo-dock-plugins-%%{mainver}.tar.gz
# Some contents removed: see https://bugzilla.redhat.com/show_bug.cgi?id=1178912
Source0: cairo-dock-plugins-fedora-%{tarballver}.tar.gz
# Source0 is created from Source1
Source1: cairo-dock-plug-ins-create-fedora-tarball.sh
# Port to WebKit2
Patch11: cairo-dock-plugins-3.4.1-port-WebKit2.patch
# PEP632: switch from distutils to setuptools
Patch12: cairo-dock-plugins-3.4.1-python-pep632-distutils-port.patch
# https://fedoraproject.org/wiki/Changes/Remove_webkit2gtk-4.0_API_Version
# Use webkit2gtk-4.1 for F-39+
Patch13: cairo-dock-plugins-3.4.1-port-WebKit2_gtk41.patch
# https://github.com/Cairo-Dock/cairo-dock-plug-ins/pull/16
# vala: move generated C source from vala source properly
Patch14: cairo-dock-plugins-pr16--vala-move-generated-C-source-from-vala-source-proper.patch
BuildRequires: gcc-c++
BuildRequires: cmake
BuildRequires: gettext
BuildRequires: pkgconfig(gldi) = %{core_least_ver}
BuildRequires: pkgconfig(gldi) >= %{core_least_ver}
BuildRequires: pkgconfig(glib-2.0)
BuildRequires: pkgconfig(gio-2.0)
BuildRequires: cairo-dock-devel >= %{core_least_ver}
# Plug-ins
BuildRequires: pkgconfig(ayatana-indicator3-0.4)
BuildRequires: pkgconfig(alsa)
BuildRequires: pkgconfig(dbusmenu-glib-0.4)
BuildRequires: pkgconfig(dbusmenu-gtk3-0.4)
BuildRequires: pkgconfig(fftw3)
BuildRequires: pkgconfig(gnome-vfs-2.0)
BuildRequires: pkgconfig(indicator3-0.4)
BuildRequires: pkgconfig(json-c)
BuildRequires: pkgconfig(libexif)
BuildRequires: pkgconfig(libgnome-menu-3.0)
BuildRequires: pkgconfig(libgnomeui-2.0)
@ -68,11 +73,7 @@ BuildRequires: pkgconfig(upower-glib)
BuildRequires: pkgconfig(vte-2.91)
# https://fedoraproject.org/wiki/Changes/Remove_webkit2gtk-4.0_API_Version
# Use webkit2gtk-4.1 for F-39+
%if 0%{?fedora} >= 39
BuildRequires: pkgconfig(webkit2gtk-4.1)
%else
BuildRequires: pkgconfig(webkit2gtk-4.0)
%endif
BuildRequires: pkgconfig(xxf86vm)
BuildRequires: pkgconfig(zeitgeist-2.0)
@ -91,7 +92,7 @@ Requires: %{name}-base%{?_isa} = %{version}-%{release}
Requires: %{name}-dbus%{?_isa} = %{version}-%{release}
# cairo-dock-launcher-API-daemon is written in python,
# so for now make this depending on python
Requires: cairo-dock-python3 = %{version}-%{release}
Requires: cairo-dock-python3%{?_isa} = %{version}-%{release}
# Require xdg-utils for logout by default
Requires: xdg-utils
@ -102,6 +103,9 @@ This package is a meta package for Cairo-Dock plugins.
Summary: Base files for Cairo-Dock plugins
Requires: cairo-dock-core%{?_isa} >= %{core_least_ver}
Requires: %{name}-common = %{version}-%{release}
%if 0%{?fedora} >= 41
Requires: gdk-pixbuf2-modules-extra
%endif
%description base
This package contains plug-ins files for Cairo-Dock.
@ -165,7 +169,7 @@ Requires: cairo-dock-core >= %{core_least_ver}
Requires: %{name}-dbus = %{version}-%{release}
Requires: python3-gobject
Requires: python3-dbus
BuildArch: noarch
Obsoletes: cairo-dock-python3 < 3.5.99^20241007git019f49f-1
%description -n cairo-dock-python3
This package contains Python3 binding files for Cairo-Dock
@ -173,7 +177,7 @@ This package contains Python3 binding files for Cairo-Dock
%package -n cairo-dock-ruby
Summary: Ruby binding for Cairo-Dock
Requires: cairo-dock-core >= %{core_least_ver}
Requires: %{name}-common = %{version}-%{release}
Requires: %{name}-dbus = %{version}-%{release}
Requires: ruby(release)
Requires: rubygem(ruby-dbus)
Requires: rubygem(parseconfig)
@ -202,10 +206,6 @@ binding for Cairo-Dock.
%prep
%setup -q -n cairo-dock-plugins-%{mainver}%{?use_git:-%{gitdate}git%{shorthash}}
%patch -P11 -p1 -b .wk2
%patch -P12 -p1 -b .pep632
%patch -P13 -p1 -b .wk2_gtk41
%patch -P14 -p1 -b .vala
## permission
# %%_fixperms cannot fix permissions completely here
@ -242,7 +242,9 @@ sed -i.installdir \
CMakeLists.txt
# Modify version forcely
sed -i CMakeLists.txt -e '\@set (VERSION @s|VERSION.*|VERSION "%{mainver}")|'
%if 0%{?use_git}
sed -i CMakeLists.txt -e '\@set (\(CORE_REQUIRED_\|\)VERSION @s|VERSION.*|VERSION "%{mainver}")|'
%endif
# Kill python2 explicitly
sed -i.py2 CMakeLists.txt -e 's|python2)|python2-nono)|'
@ -250,36 +252,35 @@ sed -i.py2 CMakeLists.txt -e 's|python2)|python2-nono)|'
env LANG=C grep -rl /usr/bin/env . | \
xargs sed -i -e 's|/usr/bin/env[ \t]*python$|/usr/bin/python3|'
# Quick-and-dirty workaround for libetpan 1.9.4 change using pkgconfig
mkdir TMPBINDIR
cat > TMPBINDIR/libetpan-config <<EOF
#!/usr/bin/bash
exec pkg-config \$@ libetpan
EOF
chmod 0755 TMPBINDIR/libetpan-config
# Use recent standard
sed -i.std CMakeLists.txt -e 's|-std=gnu99 ||'
%build
export PATH=${PATH}:$(pwd)/TMPBINDIR
%set_build_flags
%if 0%{?use_gcc_strict_sanitize}
export CC="${CC} -fsanitize=address -fsanitize=undefined"
export CXX="${CXX} -fsanitize=address -fsanitize=undefined"
export LDFLAGS="${LDFLAGS} -pthread"
%endif
rm -f CMakeCache.txt
%cmake -B. \
%cmake \
%if 0%{?build_unstable} >= 1
-Denable-disks=TRUE \
-Denable-doncky=TRUE \
-Denable-global-menu=TRUE \
-Denable-network-monitor=TRUE \
-Denable-weblets=TRUE \
%if 0
-Denable-scooby-do=TRUE \
%endif
%endif
.
%make_build
%cmake_build
%install
%make_install \
INSTALL="install -p"
%cmake_install
# Collect documents
rm -rf documents licenses documents-dbus
@ -382,9 +383,10 @@ popd
%files dbus
%doc documents-dbus/*
%{_libdir}/cairo-dock/*Dbus*
%{_datadir}/cairo-dock/plug-ins/Dbus/
# The following is for cairo-dock-vala-devel
%exclude %{_datadir}/cairo-dock/plug-ins/Dbus/CDApplet.h
%dir %{dbus_datadir}
%{dbus_datadir}/CDBashApplet.sh
%{dbus_datadir}/Dbus.conf
%{dbus_datadir}/icon.svg
%files xfce
%{_libdir}/cairo-dock/*xfce*
@ -399,14 +401,13 @@ popd
%{_datadir}/cairo-dock/plug-ins/*weblet*
%files -n cairo-dock-python3
%{python3_sitelib}/CairoDock.py*
%{python3_sitelib}/CDApplet.py*
%{python3_sitelib}/CDBashApplet.py*
%{python3_sitelib}/*.egg-info
%{python3_sitelib}/__pycache__/
%{dbus_datadir}/CairoDock.py*
%{dbus_datadir}/CDApplet.py*
%{dbus_datadir}/CDBashApplet.py*
%{dbus_datadir}/__pycache__/
%files -n cairo-dock-ruby
%{ruby_vendorlib}/CDApplet.rb
%{dbus_datadir}/CDApplet.rb
%files -n cairo-dock-vala
%{_libdir}/libCDApplet.so.1*
@ -418,6 +419,123 @@ popd
%{_datadir}/cairo-dock/plug-ins/Dbus/CDApplet.h
%changelog
* Tue Dec 23 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.6.2-1
- 3.6.2
* Tue Nov 04 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.6.1-1
- 3.6.1
* Wed Oct 01 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.6.0-1
- 3.6.0
* Wed Sep 24 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250922gitf45372c-1.rc9
- Update to the latest git (20250922gitf45372c)
* Fri Sep 19 2025 Python Maint <python-maint@redhat.com> - 3.5.99^20250909git097b119-2.rc9
- Rebuilt for Python 3.14.0rc3 bytecode
* Wed Sep 17 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250909git097b119-1.rc9
- Update to the latest git (20250909git097b119)
* Mon Sep 08 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250908gitac4c5fc-1.rc9
- Update to the latest git (20250908gitac4c5fc)
* Sun Aug 24 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250822gitcb4e816-1.rc7
- Update to the latest git (20250822gitcb4e816)
* Fri Aug 15 2025 Python Maint <python-maint@redhat.com> - 3.5.99^20250810git987890d-2.rc6
- Rebuilt for Python 3.14.0rc2 bytecode
* Tue Aug 12 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250810git987890d-1.rc6
- Update to the latest git (20250810git987890d)
* Tue Jul 29 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250729giteb8fa4c-1.rc5
- Update to the latest git (20250729giteb8fa4c)
* Wed Jul 23 2025 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.99^20250714gita426778-2.rc4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_43_Mass_Rebuild
* Mon Jul 14 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250714gita426778-1.rc4
- Update to the latest git (20250714gita426778)
* Mon Jun 30 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250623git64bcb0f-1.rc3
- Update to the latest git (20250623git64bcb0f)
* Thu Jun 19 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250616gitd333ad8-1.rc2
- Update to the latest git (20250616gitd333ad8)
* Mon Jun 02 2025 Python Maint <python-maint@redhat.com> - 3.5.99^20250502gitd41b3c2-2.rc2
- Rebuilt for Python 3.14
* Sun May 04 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250502gitd41b3c2-1.rc2
- Update to the latest git (20250502gitd41b3c2)
* Thu Apr 17 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250218gitd591880-3.rc2
- Update %%cmake macro usage (to prepare for cmake 4 and related changes)
* Fri Mar 14 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250218gitd591880-2.rc2
- Use recent compiler standard
* Tue Feb 18 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250218gitd591880-1.rc2
- Update to the latest git (20250218gitd591880)
* Sun Feb 16 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250214git2fabf99-2.rc2
- Add BR: json-c for weather module
* Fri Feb 14 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250214git2fabf99-1.rc2
- Update to the latest git (20250214git2fabf99)
* Thu Feb 13 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250211git4793755-1.rc1
- Update to the latest git (20250211git4793755)
* Thu Jan 30 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250120git9cc48a3-1.rc1
- Update to the latest git (20250120git9cc48a3)
* Sun Jan 19 2025 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20250118git18ad738-1.beta7
- Update to the latest git (20250118git18ad738)
* Thu Jan 16 2025 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.99^20241217gitf8ad97e-2.beta6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild
* Tue Dec 17 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20241217gitf8ad97e-1.beta6
- Update to the latest git (20241217gitf8ad97e)
* Mon Dec 16 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20241216gitce0764f-1.beta6
- Update to the latest git (20241216gitce0764f)
* Sun Dec 08 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20241207gitce518e9-1
- Update to the latest git (20241207gitce518e9)
* Tue Nov 19 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20241117gite9d3fcd-1
- Update to the latest git (3.5.99-20241117gite9d3fcd)
* Thu Oct 24 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20241024gitd965212-1
- Update to the latest git (20241024gitd965212)
* Sun Oct 06 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20241007git019f49f-1
- Update to the latest git (20241007git019f49f)
* Sun Sep 22 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20240501git9901f7d-5
- BR: ayatana-indicator3-0.4 for Messaging-Menu support
* Fri Aug 16 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20240501git9901f7d-4
- Require gdk-pixbuf2-modules-extra if available
* Wed Jul 17 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.99^20240501git9901f7d-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild
* Fri Jun 07 2024 Python Maint <python-maint@redhat.com> - 3.5.99^20240501git9901f7d-2
- Rebuilt for Python 3.13
* Sat May 04 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.99^20240501git9901f7d-1
- Update to the latest git (20240501git9901f7d)
* Wed Mar 27 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.0-4
- Fix invalid SPDX tag
* Fri Mar 15 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.0-3
- SPDX migration
* Fri Mar 08 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.5.0-2
- vala: regenerate C source from vala source properly
and reenable -Werror=incompatible-pointer-types

View file

@ -1,77 +0,0 @@
--- cairo-dock-plugins-3.4.1/CMakeLists.txt.wk2 2017-04-01 03:09:09.171381809 +0900
+++ cairo-dock-plugins-3.4.1/CMakeLists.txt 2017-04-01 03:09:09.172381805 +0900
@@ -1391,7 +1391,7 @@
set (with_weblets no)
enable_if_not_defined (enable-weblets)
if (enable-weblets)
- set (WEBKIT_MODULE webkitgtk-3.0)
+ set (WEBKIT_MODULE webkit2gtk-4.0)
pkg_check_modules (WEBKIT ${WEBKIT_MODULE})
if (NOT WEBKIT_FOUND)
message (STATUS "Could not find ${WEBKIT_MODULE}; Cairo-Dock won't be built with Weblets applet.")
--- cairo-dock-plugins-3.4.1/weblets/src/applet-struct.h.wk2 2015-02-20 01:13:47.000000000 +0900
+++ cairo-dock-plugins-3.4.1/weblets/src/applet-struct.h 2017-04-01 03:09:09.172381805 +0900
@@ -28,7 +28,7 @@
#include "config.h"
#endif
-#include <webkit/webkit.h>
+#include <webkit2/webkit2.h>
//\___________ structure containing the applet's configuration parameters.
struct _AppletConfig {
--- cairo-dock-plugins-3.4.1/CMakeLists.txt.wk2gtk41 2023-05-07 14:45:32.239862573 +0900
+++ cairo-dock-plugins-3.4.1/CMakeLists.txt 2023-05-07 15:18:05.558277847 +0900
@@ -1401,9 +1401,13 @@ message (STATUS "> Weblets:")
set (with_weblets no)
enable_if_not_defined (enable-weblets)
if (enable-weblets)
- set (WEBKIT_MODULE webkit2gtk-4.0)
+ set (WEBKIT_MODULE webkit2gtk-4.1)
pkg_check_modules (WEBKIT ${WEBKIT_MODULE})
if (NOT WEBKIT_FOUND)
+ set (WEBKIT_MODULE webkit2gtk-4.0)
+ pkg_check_modules (WEBKIT ${WEBKIT_MODULE})
+ endif()
+ if (NOT WEBKIT_FOUND)
message (STATUS "Could not find ${WEBKIT_MODULE}; Cairo-Dock won't be built with Weblets applet.")
message (WARNING "This module is required to compile Weblets applet: ${WEBKIT_MODULE}")
set (MODULES_MISSING "${MODULES_MISSING} ${WEBKIT_MODULE}")

View file

@ -1,22 +0,0 @@
--- cairo-dock-plugins-gitf24f769/Dbus/interfaces/bash/setup.py.orig 2021-07-30 22:29:55.000000000 +0900
+++ cairo-dock-plugins-gitf24f769/Dbus/interfaces/bash/setup.py 2023-01-03 18:54:57.725397471 +0900
@@ -13,7 +13,7 @@
# GNU General Public License for more details.
# http://www.gnu.org/licenses/licenses.html#GPL
-from distutils.core import setup
+from setuptools import setup
setup(name='CDBashApplet',
version='1.0',
license='GPL-3',
--- cairo-dock-plugins-gitf24f769/Dbus/interfaces/python/setup.py.orig 2021-07-30 22:29:55.000000000 +0900
+++ cairo-dock-plugins-gitf24f769/Dbus/interfaces/python/setup.py 2023-01-03 18:55:05.840402277 +0900
@@ -13,7 +13,7 @@
# GNU General Public License for more details.
# http://www.gnu.org/licenses/licenses.html#GPL
-from distutils.core import setup
+from setuptools import setup
setup(name='CDApplet',
version='1.0',
license='GPL-3',

View file

@ -1,27 +0,0 @@
From f771b2233d4c5157238b78b4d4e344815dd93ff4 Mon Sep 17 00:00:00 2001
From: Mamoru TASAKA <mtasaka@fedoraproject.org>
Date: Fri, 8 Mar 2024 16:10:48 +0900
Subject: [PATCH] vala: move generated C source from vala source properly
valac generates C source from vala source and outputs the result
on the same directory as vala source.
But cmake working directory may be different
from the vala source directory. So to move generated source properly,
specify the origination directory for mv command explicitly.
---
Dbus/interfaces/vala/CMakeLists.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/Dbus/interfaces/vala/CMakeLists.txt b/Dbus/interfaces/vala/CMakeLists.txt
index d3047694e..f3d7d5fd2 100644
--- a/Dbus/interfaces/vala/CMakeLists.txt
+++ b/Dbus/interfaces/vala/CMakeLists.txt
@@ -26,7 +26,7 @@ if ("${VALAC_FOUND}" STREQUAL "TRUE")
-o ${CDAPPLET}.c
${CMAKE_CURRENT_SOURCE_DIR}/${CDAPPLET}.vala)
# it seems that valac can only produce the output c file into the current directory...
- execute_process(COMMAND mv ${CDAPPLET}.c ${VALA_DIR}/src/${CDAPPLET}.c)
+ execute_process(COMMAND mv ${CMAKE_CURRENT_SOURCE_DIR}/${CDAPPLET}.c ${VALA_DIR}/src/${CDAPPLET}.c)
# valac is a bad boy, it messes up the signal names.
execute_process(COMMAND

View file

@ -1 +1 @@
SHA512 (cairo-dock-plugins-fedora-3.5.0.tar.gz) = 0346b9715151b62907214533570213db17f3c3b49fe2c0b1c76f62eb0a28a5942d0f22bf5d7c6c22a2d1f9b2d0178d1461984291ca5aefc57f3ae58606fca60c
SHA512 (cairo-dock-plugins-fedora-3.6.2.tar.gz) = e8463af3efff540d953fd324a3a24840b355de7b0bf8c70478fc557d2a6469aab4241100096817721aa3136e305362d80e344a6ebd5f6107d70b93a9f4c5f9b4
--- cairo-dock-plugins-3.4.1/weblets/src/applet-widget.c.wk2 2015-02-20 01:13:47.000000000 +0900
+++ cairo-dock-plugins-3.4.1/weblets/src/applet-widget.c 2017-04-01 03:14:59.380001735 +0900
@@ -62,13 +62,19 @@
return gldi_dialog_new (&attr);
}
-/* Will be called when loading of the page is finished*/
-void load_finished_cb(WebKitWebView *pWebKitView, WebKitWebFrame* widget
+/* Will be called when loading of the page is changed*/
+void load_changed_cb(WebKitWebView *pWebKitView, WebKitLoadEvent load_event
, GldiModuleInstance *myApplet)
{
- cd_debug ("weblets : (re)load finished\n");
- // update scrollbars status
- show_hide_scrollbars(myApplet);
+ switch (load_event) {
+ case WEBKIT_LOAD_FINISHED:
+ cd_debug ("weblets : (re)load finished\n");
+ // update scrollbars status
+ show_hide_scrollbars(myApplet);
+ break;
+ default:
+ break;
+ }
}
/* Build the embedded widget */
@@ -80,8 +86,8 @@
myData.pWebKitView = WEBKIT_WEB_VIEW (webkit_web_view_new ());
gtk_container_add (GTK_CONTAINER (myData.pGtkMozEmbed), GTK_WIDGET (myData.pWebKitView));
g_signal_connect(G_OBJECT(myData.pWebKitView),
- "load_finished",
- G_CALLBACK (load_finished_cb),
+ "load-changed",
+ G_CALLBACK (load_changed_cb),
myApplet);
gtk_widget_show_all (myData.pGtkMozEmbed);
@@ -120,10 +126,14 @@
}
}
- webkit_web_view_open(WEBKIT_WEB_VIEW(myData.pWebKitView), myConfig.cURI_to_load?myConfig.cURI_to_load:"http://www.google.com");
+ webkit_web_view_load_uri(WEBKIT_WEB_VIEW(myData.pWebKitView), myConfig.cURI_to_load?myConfig.cURI_to_load:"http://www.google.com");
}
/* available since rev. 30985, from fev. 2008 */
- webkit_web_view_set_transparent(myData.pWebKitView, myConfig.bIsTransparent);
+ {
+ GdkRGBA rgba = {0};
+ if (myConfig.bIsTransparent) rgba.alpha = 0.5;
+ webkit_web_view_set_background_color(myData.pWebKitView, &rgba);
+ }
return TRUE;
}

View file

@ -1,17 +0,0 @@